"""
    ORY Oathkeeper

    ORY Oathkeeper is a reverse proxy that checks the HTTP Authorization for validity against a set of rules. This service uses Hydra to validate access tokens and policies.  # noqa: E501

    The version of the OpenAPI document: v0.39.4
    Contact: hi@ory.am
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_oathkeeper_client
from ory_oathkeeper_client.model.rule_handler import RuleHandler
from ory_oathkeeper_client.model.rule_match import RuleMatch
from ory_oathkeeper_client.model.upstream import Upstream
globals()['RuleHandler'] = RuleHandler
globals()['RuleMatch'] = RuleMatch
globals()['Upstream'] = Upstream
from ory_oathkeeper_client.model.rule import Rule


class TestRule(unittest.TestCase):
    """Rule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRule(self):
        """Test Rule"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Rule()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from ory_oathkeeper_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from ory_oathkeeper_client.model.get_well_known_json_web_keys500_response import GetWellKnownJSONWebKeys500Response
from ory_oathkeeper_client.model.health_not_ready_status import HealthNotReadyStatus
from ory_oathkeeper_client.model.health_status import HealthStatus
from ory_oathkeeper_client.model.json_web_key import JsonWebKey
from ory_oathkeeper_client.model.json_web_key_set import JsonWebKeySet
from ory_oathkeeper_client.model.rule import Rule
from ory_oathkeeper_client.model.rule_handler import RuleHandler
from ory_oathkeeper_client.model.rule_match import RuleMatch
from ory_oathkeeper_client.model.upstream import Upstream
from ory_oathkeeper_client.model.version import Version



"""
    ORY Oathkeeper

    ORY Oathkeeper is a reverse proxy that checks the HTTP Authorization for validity against a set of rules. This service uses Hydra to validate access tokens and policies.  # noqa: E501

    The version of the OpenAPI document: v0.39.4
    Contact: hi@ory.am
    Generated by: https://openapi-generator.tech
"""


import unittest

import ory_oathkeeper_client
from ory_oathkeeper_client.api.api_api import ApiApi  # noqa: E501


class TestApiApi(unittest.TestCase):
    """ApiApi unit test stubs"""

    def setUp(self):
        self.api = ApiApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_decisions(self):
        """Test case for decisions

        Access Control Decision API  # noqa: E501
        """
        pass

    def test_get_rule(self):
        """Test case for get_rule

        Retrieve a rule  # noqa: E501
        """
        pass

    def test_get_version(self):
        """Test case for get_version

        Get service version  # noqa: E501
        """
        pass

    def test_get_well_known_json_web_keys(self):
        """Test case for get_well_known_json_web_keys

        Lists cryptographic keys  # noqa: E501
        """
        pass

    def test_is_instance_alive(self):
        """Test case for is_instance_alive

        Check alive status  # noqa: E501
        """
        pass

    def test_is_instance_ready(self):
        """Test case for is_instance_ready

        Check readiness status  # noqa: E501
        """
        pass

    def test_list_rules(self):
        """Test case for list_rules

        List all rules  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    ORY Oathkeeper

    ORY Oathkeeper is a reverse proxy that checks the HTTP Authorization for validity against a set of rules. This service uses Hydra to validate access tokens and policies.  # noqa: E501

    The version of the OpenAPI document: v0.39.4
    Contact: hi@ory.am
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_oathkeeper_client
from ory_oathkeeper_client.model.upstream import Upstream


class TestUpstream(unittest.TestCase):
    """Upstream unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpstream(self):
        """Test Upstream"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Upstream()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
